@@ -23,7 +23,7 @@ def download_account_balances(filepath_or_buffer=None, output="csv",
                               latest=False, accounts=None, below=None,
                               fields=None, force_refresh=False):
     """
-    Query IB account balances.
+    Query account balances.
 
     Parameters
     ----------
@@ -31,7 +31,7 @@ def download_account_balances(filepath_or_buffer=None, output="csv",
         filepath to write the data to, or file-like object (defaults to stdout)
 
     output : str
-        output format (json, csv, txt, default is csv)
+        output format (json or csv, default is csv)
 
     start_date : str (YYYY-MM-DD), optional
         limit to account balance snapshots taken on or after this date
@@ -50,11 +50,12 @@ def download_account_balances(filepath_or_buffer=None, output="csv",
         amount (pass as {field:amount}, for example {'Cushion':0.05})
 
     fields : list of str, optional
-        only return these fields (pass ['?'] or any invalid fieldname to see
-        available fields)
+        only return these fields. By default a core set of fields is returned.
+        Pass a list of fields, or '*' to return all fields. Pass ['?'] or any
+        invalid fieldname to see available fields.
 
     force_refresh : bool
-        refresh account balances from IB (default is to query the
+        refresh account balances to ensure the latest data (default is to query the
         database, which is refreshed every minute)
 
     Returns
@@ -87,7 +88,7 @@ def download_account_balances(filepath_or_buffer=None, output="csv",
 
     output = output or "csv"
 
-    if output not in ("csv", "json", "txt"):
+    if output not in ("csv", "json"):
         raise ValueError("Invalid ouput: {0}".format(output))
 
     response = houston.get("/account/balances.{0}".format(output), params=params)
@@ -109,11 +110,11 @@ def _cli_download_account_balances(*args, **kwargs):
     return json_to_cli(download_account_balances, *args, **kwargs)
 
 def download_account_portfolio(filepath_or_buffer=None, output="csv",
-                               accounts=None, sec_types=None,
-                               exchanges=None, conids=None, symbols=None,
+                               brokers=None, accounts=None, sec_types=None,
+                               exchanges=None, sids=None, symbols=None,
                                include_zero=False, fields=None):
     """
-    Download current IB portfolio.
+    Download current portfolio.
 
     Parameters
     ----------
@@ -123,6 +124,9 @@ def download_account_portfolio(filepath_or_buffer=None, output="csv",
     output : str
         output format (json or csv, default is csv)
 
+    brokers : list of str, optional
+        limit to these brokers. Possible choices: alpaca, ibkr
+
     accounts : list of str, optional
         limit to these accounts
 
@@ -132,18 +136,20 @@ def download_account_portfolio(filepath_or_buffer=None, output="csv",
     exchanges : list of str, optional
         limit to these exchanges
 
-    conids : list of int, optional
-        limit to these conids
+    sids : list of str, optional
+        limit to these sids
 
     symbols : list of str, optional
         limit to these symbols
 
     include_zero : bool
-        include zero position rows (default is to exclude them)
+        include zero position rows (default is to exclude them). Only
+        supported for Interactive Brokers.
 
     fields : list of str, optional
-        only return these fields (pass ['?'] or any invalid fieldname to see
-        available fields)
+        only return these fields. By default a core set of fields is returned.
+        Pass a list of fields, or '*' to return all fields. Pass '?' or any
+        invalid fieldname to see available fields.
 
     Returns
     -------
@@ -158,14 +164,16 @@ def download_account_portfolio(filepath_or_buffer=None, output="csv",
     >>> portfolio = pd.read_csv(f, parse_dates=["LastUpdated"])
     """
     params = {}
+    if brokers:
+        params["brokers"] = brokers
     if accounts:
         params["accounts"] = accounts
     if sec_types:
         params["sec_types"] = sec_types
     if exchanges:
         params["exchanges"] = exchanges
-    if conids:
-        params["conids"] = conids
+    if sids:
+        params["sids"] = sids
     if symbols:
         params["symbols"] = symbols
     if include_zero:
@@ -209,7 +217,7 @@ def download_exchange_rates(filepath_or_buffer=None, output="csv",
         filepath to write the data to, or file-like object (defaults to stdout)
 
     output : str
-        output format (json, csv, txt, default is csv)
+        output format (json, csv, default is csv)
 
     start_date : str (YYYY-MM-DD), optional
         limit to exchange rates on or after this date
@@ -252,7 +260,7 @@ def download_exchange_rates(filepath_or_buffer=None, output="csv",
 
     output = output or "csv"
 
-    if output not in ("csv", "json", "txt"):
+    if output not in ("csv", "json"):
         raise ValueError("Invalid ouput: {0}".format(output))
 
     response = houston.get("/account/rates.{0}".format(output), params=params)
